@@ -5,10 +5,7 @@ use std::{
     io::{self, IoSlice, IoSliceMut, Read, Write},
     net::TcpStream,
 };
-use unsafe_io::{
-    os::posish::{AsRawFd, AsRawReadWriteFd, FromRawFd, IntoRawFd, RawFd},
-    OwnsRaw,
-};
+use unsafe_io::os::posish::{AsRawFd, AsRawReadWriteFd, FromRawFd, IntoRawFd, RawFd};
 
 /// A socketpair stream, which is a bidirectional bytestream much like a
 /// [`TcpStream`] except that it does not have a name or address.
@@ -145,6 +142,13 @@ impl IntoRawFd for SocketpairStream {
     }
 }
 
+impl IntoFd for SocketpairStream {
+    #[inline]
+    fn into_fd(self) -> OwnedFd {
+        self.0.into_fd()
+    }
+}
+
 impl FromRawFd for SocketpairStream {
     #[inline]
     unsafe fn from_raw_fd(raw_fd: RawFd) -> Self {
@@ -171,8 +175,17 @@ impl AsRawReadWriteFd for SocketpairStream {
     }
 }
 
-/// Safety: `SocketpairStream` wraps a `TcpStream` which owns its handle.
-unsafe impl OwnsRaw for SocketpairStream {}
+impl AsReadWriteFd for SocketpairStream {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+}
 
 impl Debug for SocketpairStream {
     #[allow(clippy::missing_inline_in_public_items)]
