@@ -6,9 +6,8 @@ use std::{
     io::{self, IoSlice, IoSliceMut, Read, Write},
     os::unix::net::UnixStream,
 };
-use unsafe_io::{
-    os::posish::{AsRawFd, AsRawReadWriteFd, FromRawFd, IntoRawFd, RawFd},
-    OwnsRaw,
+use unsafe_io::os::posish::{
+    AsRawFd, AsRawReadWriteFd, AsReadWriteFd, FromRawFd, IntoRawFd, RawFd,
 };
 #[cfg(not(unix_socket_peek))]
 use {io_lifetimes::AsSocketlike, std::net::TcpStream};
@@ -180,8 +179,17 @@ impl AsRawReadWriteFd for SocketpairStream {
     }
 }
 
-/// Safety: `SocketpairStream` wraps a `UnixStream` which owns its handle.
-unsafe impl OwnsRaw for SocketpairStream {}
+impl AsReadWriteFd for SocketpairStream {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+}
 
 impl Debug for SocketpairStream {
     #[allow(clippy::missing_inline_in_public_items)]
