@@ -11,9 +11,8 @@ use std::{
     pin::Pin,
     task::{Context, Poll},
 };
-use unsafe_io::{
-    os::posish::{AsRawFd, AsRawReadWriteFd, FromRawFd, IntoRawFd, RawFd},
-    OwnsRaw,
+use unsafe_io::os::posish::{
+    AsRawFd, AsRawReadWriteFd, AsReadWriteFd, FromRawFd, IntoRawFd, RawFd,
 };
 
 /// A socketpair stream, which is a bidirectional bytestream much like a
@@ -151,8 +150,17 @@ impl AsRawReadWriteFd for AsyncStdSocketpairStream {
     }
 }
 
-/// Safety: `SocketpairStream` wraps a `UnixStream` which owns its handle.
-unsafe impl OwnsRaw for AsyncStdSocketpairStream {}
+impl AsReadWriteFd for AsyncStdSocketpairStream {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+}
 
 impl Debug for AsyncStdSocketpairStream {
     #[allow(clippy::missing_inline_in_public_items)]
