@@ -11,10 +11,7 @@ use tokio::{
     io::{self, AsyncRead, AsyncWrite, ReadBuf},
     net::UnixStream,
 };
-use unsafe_io::{
-    os::posish::{AsRawFd, AsRawReadWriteFd, RawFd},
-    OwnsRaw,
-};
+use unsafe_io::os::posish::{AsRawFd, AsRawReadWriteFd, AsReadWriteFd, RawFd};
 
 /// A socketpair stream, which is a bidirectional bytestream much like a
 /// [`UnixStream`] except that it does not have a name or address.
@@ -113,8 +110,17 @@ impl AsRawReadWriteFd for TokioSocketpairStream {
     }
 }
 
-/// Safety: `SocketpairStream` wraps a `UnixStream` which owns its handle.
-unsafe impl OwnsRaw for TokioSocketpairStream {}
+impl AsReadWriteFd for TokioSocketpairStream {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+}
 
 impl Debug for TokioSocketpairStream {
     #[allow(clippy::missing_inline_in_public_items)]
