@@ -6,6 +6,7 @@ use async_std::{
     os::windows::io::{AsRawHandle, FromRawHandle, IntoRawHandle, RawHandle},
     path::Path,
 };
+use io_lifetimes::{AsHandle, BorrowedHandle, IntoHandle, OwnedHandle};
 use std::{
     convert::TryInto,
     fmt::{self, Debug},
@@ -14,11 +15,10 @@ use std::{
     ptr,
     task::{Context, Poll},
 };
-use unsafe_io::{
-    os::windows::{
-        AsRawHandleOrSocket, AsRawReadWriteHandleOrSocket, IntoRawHandleOrSocket, RawHandleOrSocket,
-    },
-    OwnsRaw,
+use unsafe_io::os::windows::{
+    AsHandleOrSocket, AsRawHandleOrSocket, AsRawReadWriteHandleOrSocket, AsReadWriteHandleOrSocket,
+    BorrowedHandleOrSocket, IntoHandleOrSocket, IntoRawHandleOrSocket, OwnedHandleOrSocket,
+    RawHandleOrSocket,
 };
 use uuid::Uuid;
 use winapi::{
@@ -168,6 +168,13 @@ impl AsRawHandle for AsyncStdSocketpairStream {
     }
 }
 
+impl AsHandle for AsyncStdSocketpairStream {
+    #[inline]
+    fn as_handle(&self) -> BorrowedHandle<'_> {
+        self.0.as_handle()
+    }
+}
+
 impl IntoRawHandle for AsyncStdSocketpairStream {
     #[inline]
     fn into_raw_handle(self) -> RawHandle {
@@ -175,6 +182,13 @@ impl IntoRawHandle for AsyncStdSocketpairStream {
     }
 }
 
+impl IntoHandle for AsyncStdSocketpairStream {
+    #[inline]
+    fn into_handle(self) -> OwnedHandle {
+        self.0.into_handle()
+    }
+}
+
 impl FromRawHandle for AsyncStdSocketpairStream {
     #[inline]
     unsafe fn from_raw_handle(raw_handle: RawHandle) -> Self {
@@ -189,6 +203,13 @@ impl AsRawHandleOrSocket for AsyncStdSocketpairStream {
     }
 }
 
+impl AsHandleOrSocket for AsyncStdSocketpairStream {
+    #[inline]
+    fn as_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.0.as_handle_or_socket()
+    }
+}
+
 impl IntoRawHandleOrSocket for AsyncStdSocketpairStream {
     #[inline]
     fn into_raw_handle_or_socket(self) -> RawHandleOrSocket {
@@ -196,6 +217,13 @@ impl IntoRawHandleOrSocket for AsyncStdSocketpairStream {
     }
 }
 
+impl IntoHandleOrSocket for AsyncStdSocketpairStream {
+    #[inline]
+    fn into_handle_or_socket(self) -> OwnedHandleOrSocket {
+        self.0.into_handle_or_socket()
+    }
+}
+
 impl AsRawReadWriteHandleOrSocket for AsyncStdSocketpairStream {
     #[inline]
     fn as_raw_read_handle_or_socket(&self) -> RawHandleOrSocket {
@@ -208,9 +236,17 @@ impl AsRawReadWriteHandleOrSocket for AsyncStdSocketpairStream {
     }
 }
 
-/// Safety: `AsyncStdSocketpairStream` wraps a `TcpStream` which owns its
-/// handle.
-unsafe impl OwnsRaw for AsyncStdSocketpairStream {}
+impl AsReadWriteHandleOrSocket for AsyncStdSocketpairStream {
+    #[inline]
+    fn as_read_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_write_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+}
 
 impl Debug for AsyncStdSocketpairStream {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
